# Django - Implement (2FA) Two-Factor Authentication

In this article, you'll learn how to add two-factor (2FA) authentication to a Django REST API using TOTP tokens generated by an Authenticator app like Chrome's Authenticator extension, Authy or Google Authenticator.

![Django - Implement (2FA) Two-Factor Authentication](https://codevoweb.com/wp-content/uploads/2022/12/Django-Implement-2FA-Two-Factor-Authentication-1024x576.webp)

## Topics Covered

- Run the Django 2FA API Locally
- Run the Django 2FA API with React.js
- Setup the Django Project
- Create Django Models
    - Database Model
    - Model Serializer
- Implement the Two-Factor Authentication
    - Register User API View
    - Login User API View
    - Generate OTP API View
    - Verify OTP API View
    - Validate OTP API View
    - Disable 2FA API View
- Create URLs for the API Views
    - Create the APP URLs
    - Include the Base URL in the Project
- Add CORS Middleware
- Test the Two-Factor Authentication API
    - Generate the 2FA QRCode
    - Enable the 2FA Feature
    - Validate the TOTP
    - Disable the 2FA Feature
- Create API Documentation


Read the entire article here: [https://codevoweb.com/django-implement-2fa-two-factor-authentication/](https://codevoweb.com/django-implement-2fa-two-factor-authentication/)

Related articles:

1. [Two-factor Authentication (2FA) in FastAPI and Python](https://codevoweb.com/two-factor-authentication-2fa-in-fastapi-and-python/)
2. [How to Implement (2FA) Two-factor Authentication in Golang](https://codevoweb.com/two-factor-authentication-2fa-in-golang/)
3. [How to Implement (2FA) Two-factor Authentication in Node.js](https://codevoweb.com/two-factor-authentication-2fa-in-nodejs/)
4. [How to Implement Two-factor Authentication (2FA) in React.js](https://codevoweb.com/two-factor-authentication-2fa-in-reactjs/)

